sqlobject.tests.dbtest module — SQLObject 3.9.1 documentation

# sqlobject.tests.dbtest module

The framework for making database tests.

class `sqlobject.tests.dbtest.` `Dummy`(**kw)

  Bases: `object`

  Used for creating fake objects; a really poor ‘mock object’.

`sqlobject.tests.dbtest.` `deprecated_module`()

`sqlobject.tests.dbtest.` `getConnection`(**kw)

`sqlobject.tests.dbtest.` `getConnectionURI`()

`sqlobject.tests.dbtest.` `inserts`(cls, data, schema=None)

  Creates a bunch of rows.

  You can use it like:

      inserts(Person, [{'fname': 'blah', 'lname': 'doe'}, ...])

  Or:

      inserts(Person, [('blah', 'doe')], schema=
              ['fname', 'lname'])

  If you give a single string for the schema then it’ll split that string to get the list of column names.

`sqlobject.tests.dbtest.` `raises`(expected_exception: Union[Type[_E], Tuple[Type[_E], …]], *args: Any, **kwargs: Any) → Union[RaisesContext[_E], _pytest._code.code.ExceptionInfo[_E]]

  Assert that a code block/function call raises `expected_exception` or raise a failure exception otherwise.

  Parameters

    match –

    If specified, a string containing a regular expression, or a regular expression object, that is tested against the string representation of the exception using `re.search`. To match a literal string that may contain special characters, the pattern can first be escaped with `re.escape`.

    (This is only used when `pytest.raises` is used as a context manager, and passed through to the function otherwise. When using `pytest.raises` as a function, you can use: `pytest.raises(Exc, func, match="passed on").match("my pattern")`.)

  Use `pytest.raises` as a context manager, which will capture the exception of the given type:

      >>> with raises(ZeroDivisionError):
      ...    1/0

  If the code block does not raise the expected exception (`ZeroDivisionError` in the example above), or no exception at all, the check will fail instead.

  You can also use the keyword argument `match` to assert that the exception matches a text or regex:

      >>> with raises(ValueError, match='must be 0 or None'):
      ...     raise ValueError("value must be 0 or None")

      >>> with raises(ValueError, match=r'must be \d+$'):
      ...     raise ValueError("value must be 42")

  The context manager produces an `ExceptionInfo` object which can be used to inspect the details of the captured exception:

      >>> with raises(ValueError) as exc_info:
      ...     raise ValueError("value must be 42")
      >>> assert exc_info.type is ValueError
      >>> assert exc_info.value.args[0] == "value must be 42"

  Note

  When using `pytest.raises` as a context manager, it’s worthwhile to note that normal context manager rules apply and that the exception raised must be the final line in the scope of the context manager. Lines of code after that, within the scope of the context manager will not be executed. For example:

      >>> value = 15
      >>> with raises(ValueError) as exc_info:
      ...     if value > 10:
      ...         raise ValueError("value must be <= 10")
      ...     assert exc_info.type is ValueError  # this will not execute

  Instead, the following approach must be taken (note the difference in scope):

      >>> with raises(ValueError) as exc_info:
      ...     if value > 10:
      ...         raise ValueError("value must be <= 10")
      ...
      >>> assert exc_info.type is ValueError

  Using with `pytest.mark.parametrize`

  When using pytest.mark.parametrize ref it is possible to parametrize tests such that some runs raise an exception and others do not.

  See parametrizing_conditional_raising for an example.

  Legacy form

  It is possible to specify a callable by passing a to-be-called lambda:

      >>> raises(ZeroDivisionError, lambda: 1/0)
      <ExceptionInfo ...>

  or you can specify an arbitrary callable with arguments:

      >>> def f(x): return 1/x
      ...
      >>> raises(ZeroDivisionError, f, 0)
      <ExceptionInfo ...>
      >>> raises(ZeroDivisionError, f, x=0)
      <ExceptionInfo ...>

  The form above is fully supported but discouraged for new code because the context manager form is regarded as more readable and less error-prone.

  Note

  Similar to caught exception objects in Python, explicitly clearing local references to returned `ExceptionInfo` objects can help the Python interpreter speed up its garbage collection.

  Clearing those references breaks a reference cycle (`ExceptionInfo` –> caught exception –> frame stack raising the exception –> current frame stack –> local variables –> `ExceptionInfo`) which makes Python keep all objects referenced from that cycle (including all local variables in the current frame) alive until the next cyclic garbage collection run. More detailed information can be found in the official Python documentation for the try statement.

`sqlobject.tests.dbtest.` `setupClass`(soClasses, force=False)

  Makes sure the classes have a corresponding and correct table. This won’t recreate the table if it already exists. It will check that the table is properly defined (in case you change your table definition).

  You can provide a single class or a list of classes; if a list then classes will be created in the order you provide, and destroyed in the opposite order. So if class A depends on class B, then do setupClass([B, A]) and B won’t be destroyed or cleared until after A is destroyed or cleared.

  If force is true, then the database will be recreated no matter what.

`sqlobject.tests.dbtest.` `setupCyclicClasses`(*classes)

`sqlobject.tests.dbtest.` `setupLogging`()

`sqlobject.tests.dbtest.` `setup_module`(mod)

`sqlobject.tests.dbtest.` `supports`(feature)

`sqlobject.tests.dbtest.` `teardown_module`(mod=None)